@@ -8,6 +8,24 @@ from treetopper._pdf_print import PDF
 from treetopper._constants import extension_check
 
 
+NOT_FULL_THIN_MESSAGE = """
+** COULD NOT ACHIEVE TARGET DENSITY OF {target} {thin_param} **
+** THINNING PARAMETERS ONLY ALLOWED {actual} {thin_param} OF THE {needed} {thin_param} NEEDED TO BE HARVESTED **
+   THINNING PARAMETERS:
+   \tSPECIES: {species}
+   \tMIN DBH: {min_dbh}
+   \tMAX DBH: {max_dbh}
+"""
+
+SUCCESS_MESSAGE = """
+TARGET DENSITY OF {target} {thin_param} ACHIEVED
+THINNING PARAMETERS:
+   \tSPECIES: {species}
+   \tMIN DBH: {min_dbh}
+   \tMAX DBH: {max_dbh}
+"""
+
+
 class Thin(object):
     """The Thin Class is the parent class of the three thinning child classes: ThinTPA, ThinBA, and ThinRD.
 
@@ -38,6 +56,8 @@ class Thin(object):
         self.adds = [['ba_ac', 'ba_tree'], ['rd_ac', 'rd_tree'], ['bf_ac', 'bf_tree'], ['cf_ac', 'cf_tree']]
         self.conditions = ['current_', 'residual_', 'removal_']
 
+        self.report_message = None
+
         for key in self.keys:
             setattr(self, f'{self.conditions[0]}{key}', 0)
 
@@ -47,26 +67,25 @@ class Thin(object):
         return self.__dict__[attribute]
 
     def console_report(self):
-        """Prints a report to the console of the stands conditions: current, removals, and residual shown by species and totals"""
+        """Returns a console-formatted string of the stands conditions: current, removals, and residual shown by species and totals,
+        to be called by the standard print() function"""
         species, min_dbh, max_dbh = self._get_message_params_report()
+        thin_param = self.full_thin[2].replace('_', '/').upper()
+        console_text = '\nTHINNING RESULTS\n'
         if not self.full_thin[0]:
-            needed = round(self[f'current_{self.full_thin[2]}'] - self.target)
-            message = f"""\n** COULD NOT ACHIEVE TARGET DENSITY OF {self.target} {self.full_thin[2].replace('_', ' ').upper()} **
-** THINNING PARAMETERS ONLY ALLOWED {round(self.full_thin[1], 1)} {self.full_thin[2].replace('_', '/').upper()} OF THE {needed} NEEDED TO BE HARVESTED **
-   THINNING PARAMETERS:
-   \tSPECIES: {', '.join(species)}
-   \tMIN DBH: {min_dbh}
-   \tMAX DBH: {max_dbh}\n"""
-            print(message)
-            print_thin_species(self.species_data)
+            needed = round(self[f'current_{self.full_thin[2]}'] - self.target, 1)
+            self.report_message = NOT_FULL_THIN_MESSAGE.format(target=self.target, thin_param=thin_param,
+                                                               actual=round(self.full_thin[1], 1), needed=needed,
+                                                               species=', '.join(species), min_dbh=min_dbh, max_dbh=max_dbh)
+            console_text += self.report_message
+            console_text += print_thin_species(self.species_data)
         else:
-            message = f"""\nTARGET DENSITY OF {self.target} {self.full_thin[2].replace('_', '/').upper()} ACHIEVED
-THINNING PARAMETERS:
-   \tSPECIES: {', '.join(species)}
-   \tMIN DBH: {min_dbh}
-   \tMAX DBH: {max_dbh}\n"""
-            print(message)
-            print_thin_species(self.species_data)
+            self.report_message = SUCCESS_MESSAGE.format(target=self.target, thin_param=thin_param, species=', '.join(species),
+                                                         min_dbh=min_dbh, max_dbh=max_dbh)
+            console_text += self.report_message
+            console_text += print_thin_species(self.species_data)
+        # print(console_text)
+        return console_text
 
     def pdf_report(self, filename: str, directory: str = None):
         """Exports a pdf of the thinning report to a user specified directory or if directory is None, to the current working directory"""
@@ -230,7 +249,7 @@ THINNING PARAMETERS:
         current_density = self[f'current_{self.target_metric}']
         met = self.target_metric.replace('_', '/').upper()
         if current_density < self.target:
-            raise TargetDenistyError(self.target, current_density, met)
+            raise TargetDensityError(self.target, current_density, met)
 
 
 class ThinTPA(Thin):
@@ -266,13 +285,13 @@ class ThinRD(Thin):
         self.species_data = self._get_species_conditions()
 
 
-class TargetDenistyError(Exception):
+class TargetDensityError(Exception):
     def __init__(self, target_density, current_density, target_metric):
         p1 = f"""Target Density of {target_density} {target_metric} """
         p2 = f"""is greater than Stand Total of {round(current_density, 1)} {target_metric}. """
         p3 = f"""Please lower Target Density"""
         self.message = p1 + p2 + p3
-        super(TargetDenistyError, self).__init__(self.message)
+        super(TargetDensityError, self).__init__(self.message)
 
 
 
